@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vi:si:et:sw=4:sts=4:ts=4
 # GPL 2009
-from __future__ import division
+from __future__ import division, with_statement
 import cookielib
 import hashlib
 import os
